============
 References
============

.. toctree::
   :maxdepth: 2

.. automodule:: genenga.control
   :members:
   :show-inheritance:
   :inherited-members:

.. automodule:: genenga.convert
   :members:
   :show-inheritance:
   :inherited-members:

.. automodule:: genenga.models
   :members:
   :show-inheritance:
   :inherited-members:

.. automodule:: genenga.exceptions
   :members:
   :show-inheritance:
   :inherited-members:
